@@ -1,3 +1,4 @@
+
 /*
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
  *
@@ -20,8 +21,9 @@
 #include <QWidget>
 #include <QLabel>
 #include <QPushButton>
-#include <QSlider>
-#include <QGridLayout>
+#include <QScrollArea>
+#include <QVBoxLayout>
+#include "ukmedia_volume_slider.h"
 
 class ApplicationVolumeWidget : public QWidget
 {
@@ -32,15 +34,23 @@ public:
     friend class DeviceSwitchWidget;
 private:
     QLabel *applicationLabel;
-    QLabel *noAppLabel;
+    QLabel *systemVolumeLabel;
+    QPushButton *systemVolumeBtn;
+    UkmediaVolumeSlider *systemVolumeSlider;
+    QLabel *systemVolumeDisplayLabel;
 
+    QWidget *upWidget;
+    QWidget *systemVolumeWidget;
+    QWidget *systemVolumeSliderWidget;
+    QWidget *displayAppVolumeWidget;
     QStringList *app_volume_list;
     QLabel *appLabel;
-    QLabel *appIconLabel;
+    QPushButton *appMuteBtn;
     QPushButton *appIconBtn;
-    QLabel *appVolumeLabel;
     QSlider *appSlider;
-    QGridLayout *gridlayout;
+    QScrollArea *appArea;
+    QVBoxLayout *m_pVlayout;
+protected:
 
 };
 
